# CacheableNodeAffinity

CacheableNodeAffinity defines constraints that limit what nodes this dataset can be cached to.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**required** | [**V1NodeSelector**](V1NodeSelector.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


